==> flutter_xi_platform-0.0.3.tar.gz: lib/src/xi_event_model.dart <==
/*
 * @Author": mayqiyue 
 * @Date": 2019-08-09 10":50":19 
 * @Last Modified by": mayqiyue
 * @Last Modified time": 2019-08-09 10":58":38
 */

import 'package:flutter_xi_platform/src/xi_constants.dart';
import 'package:flutter_xi_platform/src/xi_device_info_model.dart';

enum XiEventType {
  monetization,
  userBehavior,
}

class XiEventModel {
  // Base
  late String eventName;
  late String firstLaunchTime;
  late String time;

  // IAP
  late double price;
  late String currencyCode;
  late String productId;
  late String service;
  late String? receipt;
  late String? applePassword;

  // Ad Event
  late String adPlatform;
  late String placementKey;
  late String placementId;

  // Device info
  late XiEventDeviceInfoModel deviceInfo;

  // User behavior custom info
  late Map<String, dynamic> customInfo;

  XiEventType get eventType {
    final list = [
      XiEventFirstLaunch,
      XiEventNativeAdImpression,
      XiEventNativeAdClick,
      XiEventVideoImpression,
      XiEventInterstitialImpression,
      XiEventInterstitialClick,
      XiEventIAP,
      XiEventSubscription
    ];
    if (list.contains(eventName)) {
      return XiEventType.monetization;
    } else {
      return XiEventType.userBehavior;
    }
  }

  Map<String, dynamic> toMap() {
    var map = {
      "event_name": eventName,
      "first_launch_time": firstLaunchTime,
      "time": time,
      "price": price,
      "currency_code": currencyCode,
      "product_id": productId,
      "service": service,
      "receipt": receipt,
      "applePassword": applePassword,
      "ad_platform": adPlatform,
      "placement_key": placementKey,
      "placement_id": placementId,
      "device_info": deviceInfo.toMap(),
      "custom_info": customInfo,
    };
    return map;
  }
}

==> flutter_xi_platform-0.0.5.tar.gz: lib/src/xi_event_model.dart <==
/*
 * @Author": mayqiyue 
 * @Date": 2019-08-09 10":50":19 
 * @Last Modified by": mayqiyue
 * @Last Modified time": 2019-08-09 10":58":38
 */

import 'package:flutter_xi_platform/src/xi_constants.dart';
import 'package:flutter_xi_platform/src/xi_device_info_model.dart';

enum XiEventType {
  monetization,
  userBehavior,
}

class XiEventModel {
  // Base
  late String eventName;
  late String? firstLaunchTime;
  late String? time;

  // IAP
  late double price;
  late String currencyCode;
  late String productId;
  late String service;
  late String? receipt;
  late String? applePassword;

  // Ad Event
  late String adPlatform;
  late String placementKey;
  late String placementId;

  // Device info
  late XiEventDeviceInfoModel deviceInfo;

  // User behavior custom info
  late Map<String, dynamic> customInfo;

  XiEventType get eventType {
    final list = [
      XiEventFirstLaunch,
      XiEventNativeAdImpression,
      XiEventNativeAdClick,
      XiEventVideoImpression,
      XiEventInterstitialImpression,
      XiEventInterstitialClick,
      XiEventIAP,
      XiEventSubscription
    ];
    if (list.contains(eventName)) {
      return XiEventType.monetization;
    } else {
      return XiEventType.userBehavior;
    }
  }

  Map<String, dynamic> toMap() {
    var map = {
      "event_name": eventName,
      "first_launch_time": firstLaunchTime,
      "time": time,
      "price": price,
      "currency_code": currencyCode,
      "product_id": productId,
      "service": service,
      "receipt": receipt,
      "applePassword": applePassword,
      "ad_platform": adPlatform,
      "placement_key": placementKey,
      "placement_id": placementId,
      "device_info": deviceInfo.toMap(),
      "custom_info": customInfo,
    };
    return map;
  }
}
